
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.21.2',
    'branch_nick': 'patch-0-Release__1_21_2_preparation',
    'revision_id': 'bc92f48c2ddd2c3f571fe80e9be647f5d21989bf',
    'revno': 9029
}
